@@ -1,6 +1,8 @@
 package Test::Mockify::MethodSpy;
 
 use parent 'Test::Mockify::Method';
+use strict;
+use warnings;
 
 #---------------------------------------------------------------------
 sub new {
@@ -21,4 +23,4 @@ sub _addToTypeStore {
     return;
 }
 
-1;
\ No newline at end of file
+1;
